Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(39)

Unified Diff: chrome/renderer/extensions/event_bindings.h

Issue 155707: Changed the extension.connect() API not to broadcast to all tabs. Added a (Closed)
Patch Set: review comments Created 11 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/renderer/extensions/bindings_utils.h ('k') | chrome/renderer/extensions/event_bindings.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/renderer/extensions/event_bindings.h
diff --git a/chrome/renderer/extensions/event_bindings.h b/chrome/renderer/extensions/event_bindings.h
index ea0060f89dabbac300180729c5f0d97411cb9a45..3e58ff685ab290de8bbe954f9d2552181aa7c555 100644
--- a/chrome/renderer/extensions/event_bindings.h
+++ b/chrome/renderer/extensions/event_bindings.h
@@ -10,6 +10,7 @@
#include <string>
class RenderThreadBase;
+class RenderView;
class WebFrame;
// This class deals with the javascript bindings related to Event objects.
@@ -23,14 +24,16 @@ class EventBindings {
static RenderThreadBase* GetRenderThread();
// Handle a script context coming / going away.
- static void HandleContextCreated(WebFrame* frame);
+ static void HandleContextCreated(WebFrame* frame, bool contet_script);
static void HandleContextDestroyed(WebFrame* frame);
// Calls the given function in each registered context which is listening
// for events. See comments on bindings_utils::CallFunctionInContext for
// more details.
static void CallFunction(const std::string& function_name, int argc,
- v8::Handle<v8::Value>* argv);
+ v8::Handle<v8::Value>* argv,
+ RenderView* render_view);
};
#endif // CHROME_RENDERER_EXTENSIONS_EVENT_BINDINGS_H_
« no previous file with comments | « chrome/renderer/extensions/bindings_utils.h ('k') | chrome/renderer/extensions/event_bindings.cc » ('j') | no next file with comments »
@@ -23,14 +24,16 @@ class EventBindings {
static void HandleContextDestroyed(WebFrame* frame);
- // Calls the given function in each registered context which is listening
- // for events. See comments on bindings_utils::CallFunctionInContext for
- // more details.
+ // Calls the given function in each registered context which is listening for
+ // events. If render_view is non-NULL, only call the function in contexts
+ // belonging to that view. See comments on
+ // bindings_utils::CallFunctionInContext for more details.
static void CallFunction(const std::string& function_name, int argc,

Powered by Google App Engine
This is Rietveld 408576698